@@ -1,8 +1,8 @@
 package ZMQ::FFI::Constants;
-$ZMQ::FFI::Constants::VERSION = '1.14';
+$ZMQ::FFI::Constants::VERSION = '1.19';
 # ABSTRACT: Generated module of zmq constants. All constants, all versions.
 
-# Generated using ZMQ versions v2.1.0-v4.3.1
+# Generated using ZMQ versions v2.1.0-v4.3.4
 
 use strict;
 use warnings;
@@ -14,11 +14,14 @@ ZMQ_AFFINITY
 ZMQ_BACKLOG
 ZMQ_BINDTODEVICE
 ZMQ_BLOCKY
+ZMQ_CHANNEL
 ZMQ_CLIENT
 ZMQ_CONFLATE
 ZMQ_CONNECT_RID
 ZMQ_CONNECT_ROUTING_ID
 ZMQ_CONNECT_TIMEOUT
+ZMQ_CURRENT_EVENT_VERSION
+ZMQ_CURRENT_EVENT_VERSION_DRAFT
 ZMQ_CURVE
 ZMQ_CURVE_PUBLICKEY
 ZMQ_CURVE_SECRETKEY
@@ -29,6 +32,7 @@ ZMQ_DEFINED_STDINT
 ZMQ_DELAY_ATTACH_ON_CONNECT
 ZMQ_DELIMITER
 ZMQ_DGRAM
+ZMQ_DISCONNECT_MSG
 ZMQ_DISH
 ZMQ_DONTWAIT
 ZMQ_EVENTS
@@ -50,11 +54,11 @@ ZMQ_EVENT_HANDSHAKE_SUCCEED
 ZMQ_EVENT_HANDSHAKE_SUCCEEDED
 ZMQ_EVENT_LISTENING
 ZMQ_EVENT_MONITOR_STOPPED
+ZMQ_EVENT_PIPES_STATS
 ZMQ_FAIL_UNROUTABLE
 ZMQ_FD
 ZMQ_FORWARDER
 ZMQ_GATHER
-ZMQ_GROUP_MAX_LENGTH
 ZMQ_GSSAPI
 ZMQ_GSSAPI_NT_HOSTBASED
 ZMQ_GSSAPI_NT_KRB5_PRINCIPAL
@@ -71,11 +75,13 @@ ZMQ_HAUSNUMERO
 ZMQ_HEARTBEAT_IVL
 ZMQ_HEARTBEAT_TIMEOUT
 ZMQ_HEARTBEAT_TTL
+ZMQ_HELLO_MSG
 ZMQ_HWM
 ZMQ_IDENTITY
 ZMQ_IDENTITY_FD
 ZMQ_IMMEDIATE
 ZMQ_INVERT_MATCHING
+ZMQ_IN_BATCH_SIZE
 ZMQ_IO_THREADS
 ZMQ_IO_THREADS_DFLT
 ZMQ_IPC_FILTER_GID
@@ -106,7 +112,10 @@ ZMQ_NOBLOCK
 ZMQ_NOTIFY_CONNECT
 ZMQ_NOTIFY_DISCONNECT
 ZMQ_NULL
+ZMQ_ONLY_FIRST_SUBSCRIBE
+ZMQ_OUT_BATCH_SIZE
 ZMQ_PAIR
+ZMQ_PEER
 ZMQ_PLAIN
 ZMQ_PLAIN_PASSWORD
 ZMQ_PLAIN_SERVER
@@ -116,7 +125,9 @@ ZMQ_POLLIN
 ZMQ_POLLITEMS_DFLT
 ZMQ_POLLOUT
 ZMQ_POLLPRI
+ZMQ_PRIORITY
 ZMQ_PROBE_ROUTER
+ZMQ_PROTOCOL_ERROR_WS_UNSPECIFIED
 ZMQ_PROTOCOL_ERROR_ZAP_BAD_REQUEST_ID
 ZMQ_PROTOCOL_ERROR_ZAP_BAD_VERSION
 ZMQ_PROTOCOL_ERROR_ZAP_INVALID_METADATA
@@ -149,6 +160,10 @@ ZMQ_RCVMORE
 ZMQ_RCVTIMEO
 ZMQ_RECONNECT_IVL
 ZMQ_RECONNECT_IVL_MAX
+ZMQ_RECONNECT_STOP
+ZMQ_RECONNECT_STOP_AFTER_DISCONNECT
+ZMQ_RECONNECT_STOP_CONN_REFUSED
+ZMQ_RECONNECT_STOP_HANDSHAKE_FAILED
 ZMQ_RECOVERY_IVL
 ZMQ_RECOVERY_IVL_MSEC
 ZMQ_REP
@@ -169,7 +184,9 @@ ZMQ_SNDHWM
 ZMQ_SNDMORE
 ZMQ_SNDTIMEO
 ZMQ_SOCKET_LIMIT
+ZMQ_SOCKS_PASSWORD
 ZMQ_SOCKS_PROXY
+ZMQ_SOCKS_USERNAME
 ZMQ_SRCFD
 ZMQ_STREAM
 ZMQ_STREAMER
@@ -198,8 +215,14 @@ ZMQ_VMCI_BUFFER_MIN_SIZE
 ZMQ_VMCI_BUFFER_SIZE
 ZMQ_VMCI_CONNECT_TIMEOUT
 ZMQ_VSM
+ZMQ_WSS_CERT_PEM
+ZMQ_WSS_HOSTNAME
+ZMQ_WSS_KEY_PEM
+ZMQ_WSS_TRUST_PEM
+ZMQ_WSS_TRUST_SYSTEM
 ZMQ_XPUB
 ZMQ_XPUB_MANUAL
+ZMQ_XPUB_MANUAL_LAST_VALUE
 ZMQ_XPUB_NODROP
 ZMQ_XPUB_VERBOSE
 ZMQ_XPUB_VERBOSER
@@ -219,11 +242,14 @@ sub ZMQ_AFFINITY { 4 }
 sub ZMQ_BACKLOG { 19 }
 sub ZMQ_BINDTODEVICE { 92 }
 sub ZMQ_BLOCKY { 70 }
+sub ZMQ_CHANNEL { 20 }
 sub ZMQ_CLIENT { 13 }
 sub ZMQ_CONFLATE { 54 }
 sub ZMQ_CONNECT_RID { 61 }
 sub ZMQ_CONNECT_ROUTING_ID { 61 }
 sub ZMQ_CONNECT_TIMEOUT { 79 }
+sub ZMQ_CURRENT_EVENT_VERSION { 1 }
+sub ZMQ_CURRENT_EVENT_VERSION_DRAFT { 2 }
 sub ZMQ_CURVE { 2 }
 sub ZMQ_CURVE_PUBLICKEY { 48 }
 sub ZMQ_CURVE_SECRETKEY { 49 }
@@ -234,12 +260,13 @@ sub ZMQ_DEFINED_STDINT { 1 }
 sub ZMQ_DELAY_ATTACH_ON_CONNECT { 39 }
 sub ZMQ_DELIMITER { 31 }
 sub ZMQ_DGRAM { 18 }
+sub ZMQ_DISCONNECT_MSG { 111 }
 sub ZMQ_DISH { 15 }
 sub ZMQ_DONTWAIT { 1 }
 sub ZMQ_EVENTS { 15 }
 sub ZMQ_EVENT_ACCEPTED { 32 }
 sub ZMQ_EVENT_ACCEPT_FAILED { 64 }
-sub ZMQ_EVENT_ALL { 0 }
+sub ZMQ_EVENT_ALL { 65535 }
 sub ZMQ_EVENT_BIND_FAILED { 16 }
 sub ZMQ_EVENT_CLOSED { 128 }
 sub ZMQ_EVENT_CLOSE_FAILED { 256 }
@@ -255,11 +282,11 @@ sub ZMQ_EVENT_HANDSHAKE_SUCCEED { 4096 }
 sub ZMQ_EVENT_HANDSHAKE_SUCCEEDED { 4096 }
 sub ZMQ_EVENT_LISTENING { 8 }
 sub ZMQ_EVENT_MONITOR_STOPPED { 1024 }
+sub ZMQ_EVENT_PIPES_STATS { 65536 }
 sub ZMQ_FAIL_UNROUTABLE { 33 }
 sub ZMQ_FD { 14 }
 sub ZMQ_FORWARDER { 2 }
 sub ZMQ_GATHER { 16 }
-sub ZMQ_GROUP_MAX_LENGTH { 15 }
 sub ZMQ_GSSAPI { 3 }
 sub ZMQ_GSSAPI_NT_HOSTBASED { 0 }
 sub ZMQ_GSSAPI_NT_KRB5_PRINCIPAL { 2 }
@@ -276,11 +303,13 @@ sub ZMQ_HAUSNUMERO { 156384712 }
 sub ZMQ_HEARTBEAT_IVL { 75 }
 sub ZMQ_HEARTBEAT_TIMEOUT { 77 }
 sub ZMQ_HEARTBEAT_TTL { 76 }
+sub ZMQ_HELLO_MSG { 110 }
 sub ZMQ_HWM { 1 }
 sub ZMQ_IDENTITY { 5 }
 sub ZMQ_IDENTITY_FD { 67 }
 sub ZMQ_IMMEDIATE { 39 }
 sub ZMQ_INVERT_MATCHING { 74 }
+sub ZMQ_IN_BATCH_SIZE { 101 }
 sub ZMQ_IO_THREADS { 1 }
 sub ZMQ_IO_THREADS_DFLT { 1 }
 sub ZMQ_IPC_FILTER_GID { 60 }
@@ -311,7 +340,10 @@ sub ZMQ_NOBLOCK { 1 }
 sub ZMQ_NOTIFY_CONNECT { 1 }
 sub ZMQ_NOTIFY_DISCONNECT { 2 }
 sub ZMQ_NULL { 0 }
+sub ZMQ_ONLY_FIRST_SUBSCRIBE { 108 }
+sub ZMQ_OUT_BATCH_SIZE { 102 }
 sub ZMQ_PAIR { 0 }
+sub ZMQ_PEER { 19 }
 sub ZMQ_PLAIN { 1 }
 sub ZMQ_PLAIN_PASSWORD { 46 }
 sub ZMQ_PLAIN_SERVER { 44 }
@@ -321,7 +353,9 @@ sub ZMQ_POLLIN { 1 }
 sub ZMQ_POLLITEMS_DFLT { 16 }
 sub ZMQ_POLLOUT { 2 }
 sub ZMQ_POLLPRI { 8 }
+sub ZMQ_PRIORITY { 112 }
 sub ZMQ_PROBE_ROUTER { 51 }
+sub ZMQ_PROTOCOL_ERROR_WS_UNSPECIFIED { 805306368 }
 sub ZMQ_PROTOCOL_ERROR_ZAP_BAD_REQUEST_ID { 536870914 }
 sub ZMQ_PROTOCOL_ERROR_ZAP_BAD_VERSION { 536870915 }
 sub ZMQ_PROTOCOL_ERROR_ZAP_INVALID_METADATA { 536870917 }
@@ -354,6 +388,10 @@ sub ZMQ_RCVMORE { 13 }
 sub ZMQ_RCVTIMEO { 27 }
 sub ZMQ_RECONNECT_IVL { 18 }
 sub ZMQ_RECONNECT_IVL_MAX { 21 }
+sub ZMQ_RECONNECT_STOP { 109 }
+sub ZMQ_RECONNECT_STOP_AFTER_DISCONNECT { 3 }
+sub ZMQ_RECONNECT_STOP_CONN_REFUSED { 1 }
+sub ZMQ_RECONNECT_STOP_HANDSHAKE_FAILED { 2 }
 sub ZMQ_RECOVERY_IVL { 9 }
 sub ZMQ_RECOVERY_IVL_MSEC { 20 }
 sub ZMQ_REP { 4 }
@@ -374,7 +412,9 @@ sub ZMQ_SNDHWM { 23 }
 sub ZMQ_SNDMORE { 2 }
 sub ZMQ_SNDTIMEO { 28 }
 sub ZMQ_SOCKET_LIMIT { 3 }
+sub ZMQ_SOCKS_PASSWORD { 100 }
 sub ZMQ_SOCKS_PROXY { 68 }
+sub ZMQ_SOCKS_USERNAME { 99 }
 sub ZMQ_SRCFD { 2 }
 sub ZMQ_STREAM { 11 }
 sub ZMQ_STREAMER { 1 }
@@ -403,8 +443,14 @@ sub ZMQ_VMCI_BUFFER_MIN_SIZE { 86 }
 sub ZMQ_VMCI_BUFFER_SIZE { 85 }
 sub ZMQ_VMCI_CONNECT_TIMEOUT { 88 }
 sub ZMQ_VSM { 32 }
+sub ZMQ_WSS_CERT_PEM { 104 }
+sub ZMQ_WSS_HOSTNAME { 106 }
+sub ZMQ_WSS_KEY_PEM { 103 }
+sub ZMQ_WSS_TRUST_PEM { 105 }
+sub ZMQ_WSS_TRUST_SYSTEM { 107 }
 sub ZMQ_XPUB { 9 }
 sub ZMQ_XPUB_MANUAL { 71 }
+sub ZMQ_XPUB_MANUAL_LAST_VALUE { 98 }
 sub ZMQ_XPUB_NODROP { 69 }
 sub ZMQ_XPUB_VERBOSE { 40 }
 sub ZMQ_XPUB_VERBOSER { 78 }
@@ -431,7 +477,7 @@ ZMQ::FFI::Constants - Generated module of zmq constants. All constants, all vers
 
 =head1 VERSION
 
-version 1.14
+version 1.19
 
 =head1 SYNOPSIS
 
@@ -444,8 +490,9 @@ version 1.14
 =head1 DESCRIPTION
 
 This module includes every zmq constant from every stable version of zeromq.
-Currently that is v2.1.0-v4.3.1.  It was generated using the zeromq2-x,
-zeromq3-x, zeromq4-x, and zeromq4-1 git repos at L<https://github.com/zeromq>.
+Currently that is v2.1.0-v4.3.4.  It was generated using the zeromq2-x,
+zeromq3-x, zeromq4-x, zeromq4-1, and libzmq git repos at
+L<https://github.com/zeromq>.
 
 =head1 SEE ALSO
 
@@ -463,7 +510,7 @@ Dylan Cali <calid1984@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Dylan Cali.
+This software is copyright (c) 2023 by Dylan Cali.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
